//
//  ModulationTableViewController.m
//  AsReaderScan
//
//  Created by sps on 2021/11/08.
//

#import "ModulationTableViewController.h"
#import "ModelSettings.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>
#import "Utils.h"


#define MODULATION_BLF_160  0x00A0
#define MODULATION_BLF_250  0x00FA
#define MODULATION_BLF_320  0x0140
#define MODULATION_BLF_640  0x0280

#define FM0 0x00
#define M2  0x01
#define M4  0x02
#define M8  0x03


@interface ModulationTableViewController ()<AsReaderRFIDDeviceDelegate>{
    NSArray *modulationList;
    NSInteger selectedMoodulation;
    
}

@property (strong, nonatomic) IBOutlet UITableView *modulationTableView;

@end

@implementation ModulationTableViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    
    
    modulationList = @[@"160KHz, FM0, DR=64/3",
                       @"250KHz, FM0, DR=64/3",
                       @"320KHz, FM0, DR=64/3",
                       @"640KHz, FM0, DR=64/3",
                       @"160KHz, M2, DR=64/3",
                       @"250KHz, M2, DR=64/3",
                       @"320KHz, M2, DR=64/3",
                       @"640KHz, M2, DR=64/3",
                       @"160KHz, M4, DR=64/3",
                       @"250KHz, M4, DR=64/3",
                       @"320KHz, M4, DR=64/3",
                       @"640KHz, M4, DR=64/3",
                       @"160KHz, M8, DR=64/3",
                       @"250KHz, M8, DR=64/3",
                       @"320KHz, M8, DR=64/3",
                       @"640KHz, M8, DR=64/3"];
    
    
    selectedMoodulation = -1;

    _modulationTableView.dataSource = self;
    _modulationTableView.delegate = self;
    
    
}


- (void)viewWillAppear:(BOOL)animated{
    
    [AsReaderRFIDDevice sharedInstance].delegateRFID = self;
    
    
    [[AsReaderRFIDDevice sharedInstance]getModulation];
}

- (void)viewWillDisappear:(BOOL)animated
{
    
    [super viewWillDisappear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateRFID = nil;
}


#pragma mark - IBAction



- (IBAction)doneBtnAction:(id)sender {

    [self setModulation];
   
    dispatch_async(dispatch_get_main_queue(), ^{
        [self.tableView reloadData];
    });
}

-(void)setModulation{
    
    NSArray *modulationValueArr= [ modulationList[selectedMoodulation] componentsSeparatedByString: @","];
    
    int blf = [[[modulationValueArr objectAtIndex:0]  stringByReplacingOccurrencesOfString:@"KHz" withString:@""] intValue];
    NSString *rxMod = [modulationValueArr objectAtIndex:1];
    NSString *dr = [modulationValueArr objectAtIndex:2];
    int rxModVal =0;
    int drVal =0;
    
    if([rxMod containsString:@"FM0"]){
        rxModVal =0;
    }else if([rxMod containsString:@"M2"]){
        rxModVal =  1;
    }else if([rxMod containsString:@"M4"]){
        rxModVal =  2;
    }else if([rxMod containsString:@"M8"]){
        rxModVal =  3;
    }
    
    
    if([dr containsString:@"8"]){
        drVal =0;
    }else if([dr containsString:@"64/3"]){
        drVal =  1;
    }
    
    [[AsReaderRFIDDevice sharedInstance] setModulationBLF:blf rxMod:rxModVal dr:drVal];
}

#pragma mark - Table view data source



- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
return modulationList.count;
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{

NSString *regionCellID = @"ModulationCell";
UITableViewCell *cell = [_modulationTableView dequeueReusableCellWithIdentifier:regionCellID];

cell.textLabel.text = modulationList[indexPath.row];

if(selectedMoodulation == indexPath.row) {
    cell.accessoryType = UITableViewCellAccessoryCheckmark;
} else {
    cell.accessoryType = UITableViewCellAccessoryNone;
}
return cell;

}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{

selectedMoodulation = (int)indexPath.row;
[tableView reloadData];

}

#pragma mark - Delegate


- (void)modulationParamReceived:(int)blf rxMod:(int)rxMod dr:(int)dr{
    
    NSString *blfStr= @"";
    NSString *rxModStr= @"";

    if(blf ==0x00A0){
        blfStr =@"160KHz";
    }else if(blf ==0x00FA){
        blfStr =@"250KHz";
    }else if(blf ==0x0140){
        blfStr =@"320KHz";
    }else if (blf ==0x0280){
        blfStr =@"640KHz";
    }
    
    if(rxMod == 0x00){
        rxModStr =  @"FM0";
    }else if(rxMod == 0x01){
        rxModStr =  @"M2";
    }else if(rxMod == 0x02){
        rxModStr =  @"M4";
    }else if(rxMod == 0x03){
        rxModStr =  @"M8";
    }
    
    
    
    NSString *currentModulation = [NSString stringWithFormat:@"%@, %@, DR=64/3",blfStr,rxModStr];
    NSLog(@"%@",currentModulation);
    
    
    for(int i = 0; i < modulationList.count; i++){
        if([modulationList[i] isEqualToString: currentModulation]){
            selectedMoodulation = i;
            
            dispatch_async(dispatch_get_main_queue(), ^{
                [self.tableView reloadData];
            });
        }
    }
}



- (void)didSetModulation:(int)status{
    if( status==0xff){
        [Utils showAlert:@"" message:@"Modulation Setting Fail " view:self];
    }else{
        [Utils showAlert:@"" message:@"Modulation Setting success " view:self];
    }
    
}




@end
