//  SettingsFhLbtController.m

#import "SettingsFhLbtController.h"
#import "ModelSettings.h"
#import "Utils.h"
#import <AsReaderDockSDK/AsReaderDockSDK.h>

@interface SettingsFhLbtController ()<UITextFieldDelegate, AsReaderRFIDDeviceDelegate>

@property (nonatomic,assign)NSInteger senseTime;
@property (nonatomic,assign)NSInteger lbtLevel;
@property (nonatomic,assign)NSInteger fhEnable;
@property (nonatomic,assign)NSInteger lbtEnable;
@property (nonatomic,assign)NSInteger cwEnable;
@property (weak, nonatomic) IBOutlet UITextField *olOnTime;
@property (weak, nonatomic) IBOutlet UITextField *olOffTime;
@end

@implementation SettingsFhLbtController

#pragma mark - Lifecycle
//----------------------------------------------------------------
- (id)initWithNibName:(NSString *)nibNameOrNil bundle:(NSBundle *)nibBundleOrNil
{
    self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];

    [AsReaderRFIDDevice sharedInstance].delegateRFID = self;
    self.olOnTime.delegate = self;
    self.olOffTime.delegate = self;
    self.olOnTime.text  = [NSString stringWithFormat:@"%d", [AsReaderInfo sharedInstance].rfidOnTime];
    self.olOffTime.text = [NSString stringWithFormat:@"%d", [AsReaderInfo sharedInstance].rfidOffTime];
}

- (void)viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
    [AsReaderRFIDDevice sharedInstance].delegateRFID = nil;
    [self setOlOnTime:nil];
    [self setOlOffTime:nil];
}

#pragma mark - Private method
//----------------------------------------------------------------
- (void)showAlert:(NSString *)strMsg
{
    dispatch_async(dispatch_get_main_queue(), ^{
        [Utils showAlert:@"" message:strMsg view:self];
    });
}

- (void)onOffTimeChanged
{
     [self showAlert:@"On/OFF Time Changed"];
}

#pragma mark - IBAction
//----------------------------------------------------------------
- (IBAction)rightBarButtonItemClicked:(id)sender
{
    [self.olOnTime resignFirstResponder];
    [self.olOffTime resignFirstResponder];
    
    int nSetOnTime  = (int)[self.olOnTime.text longLongValue];
    int nSetOffTime = (int)[self.olOffTime.text longLongValue];
    [[AsReaderRFIDDevice sharedInstance]setReadTime:nSetOnTime idleTime:nSetOffTime];
}

#pragma mark -  UITextField delgate
//----------------------------------------------------------------
- (BOOL)textField:(UITextField *)textField shouldChangeCharactersInRange:(NSRange)range replacementString:(NSString *)string
{
    if ([[textField.text stringByAppendingString:string] intValue] >= 40000) {
        textField.text = @"40000";
        return NO;
    }
    return YES;
}

@end
